==> we-node-client-grpc-java-0.3.0-sources.jar: com/wavesenterprise/protobuf/service/util/UtilPublicServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.util;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.16.0)",
    comments = "Source: util/util_public_service.proto")
public final class UtilPublicServiceGrpc {

  private UtilPublicServiceGrpc() {}

  public static final String SERVICE_NAME = "wavesenterprise.grpc.UtilPublicService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getGetNodeTimeMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetNodeTime",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.util.NodeTimeResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getGetNodeTimeMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getGetNodeTimeMethod;
    if ((getGetNodeTimeMethod = UtilPublicServiceGrpc.getGetNodeTimeMethod) == null) {
      synchronized (UtilPublicServiceGrpc.class) {
        if ((getGetNodeTimeMethod = UtilPublicServiceGrpc.getGetNodeTimeMethod) == null) {
          UtilPublicServiceGrpc.getGetNodeTimeMethod = getGetNodeTimeMethod = 
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeTimeResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.grpc.UtilPublicService", "GetNodeTime"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.NodeTimeResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new UtilPublicServiceMethodDescriptorSupplier("GetNodeTime"))
                  .build();
          }
        }
     }
     return getGetNodeTimeMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static UtilPublicServiceStub newStub(io.grpc.Channel channel) {
    return new UtilPublicServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static UtilPublicServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new UtilPublicServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static UtilPublicServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new UtilPublicServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class UtilPublicServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeTimeResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getGetNodeTimeMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetNodeTimeMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                com.google.protobuf.Empty,
                com.wavesenterprise.protobuf.service.util.NodeTimeResponse>(
                  this, METHODID_GET_NODE_TIME)))
          .build();
    }
  }

  /**
   */
  public static final class UtilPublicServiceStub extends io.grpc.stub.AbstractStub<UtilPublicServiceStub> {
    private UtilPublicServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private UtilPublicServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilPublicServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new UtilPublicServiceStub(channel, callOptions);
    }

    /**
     */
    public void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeTimeResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class UtilPublicServiceBlockingStub extends io.grpc.stub.AbstractStub<UtilPublicServiceBlockingStub> {
    private UtilPublicServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private UtilPublicServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilPublicServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new UtilPublicServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.util.NodeTimeResponse getNodeTime(com.google.protobuf.Empty request) {
      return blockingUnaryCall(
          getChannel(), getGetNodeTimeMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class UtilPublicServiceFutureStub extends io.grpc.stub.AbstractStub<UtilPublicServiceFutureStub> {
    private UtilPublicServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private UtilPublicServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilPublicServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new UtilPublicServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getNodeTime(
        com.google.protobuf.Empty request) {
      return futureUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_NODE_TIME = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final UtilPublicServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(UtilPublicServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_NODE_TIME:
          serviceImpl.getNodeTime((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeTimeResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class UtilPublicServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    UtilPublicServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.util.UtilPublicServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("UtilPublicService");
    }
  }

  private static final class UtilPublicServiceFileDescriptorSupplier
      extends UtilPublicServiceBaseDescriptorSupplier {
    UtilPublicServiceFileDescriptorSupplier() {}
  }

  private static final class UtilPublicServiceMethodDescriptorSupplier
      extends UtilPublicServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    UtilPublicServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (UtilPublicServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new UtilPublicServiceFileDescriptorSupplier())
              .addMethod(getGetNodeTimeMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> we-node-client-grpc-java-2.0.0-sources.jar: com/wavesenterprise/protobuf/service/util/UtilPublicServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.util;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.64.0)",
    comments = "Source: util/util_public_service.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class UtilPublicServiceGrpc {

  private UtilPublicServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "wavesenterprise.grpc.UtilPublicService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getGetNodeTimeMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetNodeTime",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.util.NodeTimeResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getGetNodeTimeMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getGetNodeTimeMethod;
    if ((getGetNodeTimeMethod = UtilPublicServiceGrpc.getGetNodeTimeMethod) == null) {
      synchronized (UtilPublicServiceGrpc.class) {
        if ((getGetNodeTimeMethod = UtilPublicServiceGrpc.getGetNodeTimeMethod) == null) {
          UtilPublicServiceGrpc.getGetNodeTimeMethod = getGetNodeTimeMethod =
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeTimeResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GetNodeTime"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.NodeTimeResponse.getDefaultInstance()))
              .setSchemaDescriptor(new UtilPublicServiceMethodDescriptorSupplier("GetNodeTime"))
              .build();
        }
      }
    }
    return getGetNodeTimeMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static UtilPublicServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UtilPublicServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UtilPublicServiceStub>() {
        @java.lang.Override
        public UtilPublicServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UtilPublicServiceStub(channel, callOptions);
        }
      };
    return UtilPublicServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static UtilPublicServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UtilPublicServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UtilPublicServiceBlockingStub>() {
        @java.lang.Override
        public UtilPublicServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UtilPublicServiceBlockingStub(channel, callOptions);
        }
      };
    return UtilPublicServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static UtilPublicServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UtilPublicServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UtilPublicServiceFutureStub>() {
        @java.lang.Override
        public UtilPublicServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UtilPublicServiceFutureStub(channel, callOptions);
        }
      };
    return UtilPublicServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeTimeResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetNodeTimeMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service UtilPublicService.
   */
  public static abstract class UtilPublicServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return UtilPublicServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service UtilPublicService.
   */
  public static final class UtilPublicServiceStub
      extends io.grpc.stub.AbstractAsyncStub<UtilPublicServiceStub> {
    private UtilPublicServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilPublicServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UtilPublicServiceStub(channel, callOptions);
    }

    /**
     */
    public void getNodeTime(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeTimeResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service UtilPublicService.
   */
  public static final class UtilPublicServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<UtilPublicServiceBlockingStub> {
    private UtilPublicServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilPublicServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UtilPublicServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.util.NodeTimeResponse getNodeTime(com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetNodeTimeMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service UtilPublicService.
   */
  public static final class UtilPublicServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<UtilPublicServiceFutureStub> {
    private UtilPublicServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UtilPublicServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UtilPublicServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.util.NodeTimeResponse> getNodeTime(
        com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetNodeTimeMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_NODE_TIME = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_NODE_TIME:
          serviceImpl.getNodeTime((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeTimeResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getGetNodeTimeMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.google.protobuf.Empty,
              com.wavesenterprise.protobuf.service.util.NodeTimeResponse>(
                service, METHODID_GET_NODE_TIME)))
        .build();
  }

  private static abstract class UtilPublicServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    UtilPublicServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.util.UtilPublicServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("UtilPublicService");
    }
  }

  private static final class UtilPublicServiceFileDescriptorSupplier
      extends UtilPublicServiceBaseDescriptorSupplier {
    UtilPublicServiceFileDescriptorSupplier() {}
  }

  private static final class UtilPublicServiceMethodDescriptorSupplier
      extends UtilPublicServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    UtilPublicServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (UtilPublicServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new UtilPublicServiceFileDescriptorSupplier())
              .addMethod(getGetNodeTimeMethod())
              .build();
        }
      }
    }
    return result;
  }
}
